__title__ = "pygal"
__version__ = "2.4.0"

__summary__ = "A python svg graph plotting library"
__uri__ = "http://pygal.org/"
__author__ = "Florian Mounier"
__email__ = "florian.mounier@kozea.fr"

__license__ = "GNU LGPL v3+"
__copyright__ = "Copyright 2017 %s" % __author__

__all__ = [
    '__title__', '__version__', '__summary__', '__uri__', '__author__',
    '__email__', '__license__', '__copyright__'
]
